==> haskell-brick-0.19-11-i686.pkg.tar.xz: usr/share/haskell/register/haskell-brick.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: brick
version: 0.19
id: brick-0.19-HMjuh7yVpHD85PNRCgklUo
key: brick-0.19-HMjuh7yVpHD85PNRCgklUo
license: BSD3
copyright: (c) Jonathan Daugherty 2015-2016
maintainer: Jonathan Daugherty <cygnus@foobox.com>
homepage: https://github.com/jtdaugherty/brick/
synopsis: A declarative terminal user interface library
description:
    Write terminal applications painlessly with '\''brick'\''! You write an
    event handler and a drawing function and the library does the rest.
    .
    .
    > module Main where
    >
    > import Brick
    >
    > ui :: Widget ()
    > ui = str "Hello, world!"
    >
    > main :: IO ()
    > main = simpleMain ui
    .
    .
    To get started, see:
    .
    * <https://github.com/jtdaugherty/brick/blob/master/README.md The README>
    .
    * The <https://github.com/jtdaugherty/brick/blob/master/docs/guide.rst Brick user guide>
    .
    * The demonstration programs in the '\''programs'\'' directory
    .
    .
    This package deprecates <http://hackage.haskell.org/package/vty-ui vty-ui>.
category: Graphics
author: Jonathan Daugherty <cygnus@foobox.com>
exposed: True
indefinite: False
exposed-modules:
    Brick Brick.AttrMap Brick.BChan Brick.Focus Brick.Main Brick.Markup
    Brick.Types Brick.Util Brick.Widgets.Border
    Brick.Widgets.Border.Style Brick.Widgets.Center Brick.Widgets.Core
    Brick.Widgets.Dialog Brick.Widgets.Edit Brick.Widgets.List
    Brick.Widgets.ProgressBar Data.Text.Markup
hidden-modules: Brick.Types.TH Brick.Types.Internal
                Brick.Widgets.Internal
abi: f5128d6bbfbf89d2206fca32e6803d15
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/brick-0.19
library-dirs: /usr/lib/ghc-8.2.1/site-local/brick-0.19
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/brick-0.19
hs-libraries: HSbrick-0.19-HMjuh7yVpHD85PNRCgklUo
depends:
    base-4.10.0.0 vty-5.17.1-4mTiRtbjX7MIlmTyVTWpDr
    transformers-0.5.2.0 data-clist-0.1.1.0-415ZOLhdLeiK5iYjPDLw58
    dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q containers-0.5.10.2
    microlens-0.4.8.1-HUhGDwljLwYJLac51xSk3I
    microlens-th-0.4.1.1-LM8ksjmIHXtDJYY6zPs0W6
    microlens-mtl-0.1.11.0-LFsRHKdg4sqLRy6hgD5BH2
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    contravariant-1.4-1lqq0vqix8Y43XZ7Q5hTLe
    stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    text-zipper-0.10.1-5anw58L5L9nGBx6ICflo2w template-haskell-2.12.0.0
    deepseq-1.4.3.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             vty-5.17.1-4mTiRtbjX7MIlmTyVTWpDr=0742c0488c1cd6043d5f62d306e276a3
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             data-clist-0.1.1.0-415ZOLhdLeiK5iYjPDLw58=4b49a51659f14a40e41a300fc8e8f713
             dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q=39b750082c56951484aa28fb24175e9c
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             microlens-0.4.8.1-HUhGDwljLwYJLac51xSk3I=1f2768a8b45f6d673f585667eb0cb7d7
             microlens-th-0.4.1.1-LM8ksjmIHXtDJYY6zPs0W6=be9f2fe939681da641c648903d5ef4af
             microlens-mtl-0.1.11.0-LFsRHKdg4sqLRy6hgD5BH2=4b938951cf66f5c51e4cd4b36eae8e21
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             contravariant-1.4-1lqq0vqix8Y43XZ7Q5hTLe=6ad8f06d2a954a3785058f9dadfcb436
             stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ=a88f5bbac4be96a38c5ca2a658c158a0
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             text-zipper-0.10.1-5anw58L5L9nGBx6ICflo2w=72925df98680edb1f9c2bc74ba58621d
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
haddock-interfaces: /usr/share/doc/haskell-brick/html/brick.haddock
haddock-html: /usr/share/doc/haskell-brick/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-brick-0.19-12-i686.pkg.tar.xz: usr/share/haskell/register/haskell-brick.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: brick
version: 0.19
id: brick-0.19-BFDsYJYOxSCCi5PUtHAYVL
key: brick-0.19-BFDsYJYOxSCCi5PUtHAYVL
license: BSD3
copyright: (c) Jonathan Daugherty 2015-2016
maintainer: Jonathan Daugherty <cygnus@foobox.com>
homepage: https://github.com/jtdaugherty/brick/
synopsis: A declarative terminal user interface library
description:
    Write terminal applications painlessly with '\''brick'\''! You write an
    event handler and a drawing function and the library does the rest.
    .
    .
    > module Main where
    >
    > import Brick
    >
    > ui :: Widget ()
    > ui = str "Hello, world!"
    >
    > main :: IO ()
    > main = simpleMain ui
    .
    .
    To get started, see:
    .
    * <https://github.com/jtdaugherty/brick/blob/master/README.md The README>
    .
    * The <https://github.com/jtdaugherty/brick/blob/master/docs/guide.rst Brick user guide>
    .
    * The demonstration programs in the '\''programs'\'' directory
    .
    .
    This package deprecates <http://hackage.haskell.org/package/vty-ui vty-ui>.
category: Graphics
author: Jonathan Daugherty <cygnus@foobox.com>
exposed: True
indefinite: False
exposed-modules:
    Brick Brick.AttrMap Brick.BChan Brick.Focus Brick.Main Brick.Markup
    Brick.Types Brick.Util Brick.Widgets.Border
    Brick.Widgets.Border.Style Brick.Widgets.Center Brick.Widgets.Core
    Brick.Widgets.Dialog Brick.Widgets.Edit Brick.Widgets.List
    Brick.Widgets.ProgressBar Data.Text.Markup
hidden-modules: Brick.Types.TH Brick.Types.Internal
                Brick.Widgets.Internal
abi: c0181518a0dbc18233687a4a50780fc9
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/brick-0.19
library-dirs: /usr/lib/ghc-8.2.1/site-local/brick-0.19
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/brick-0.19
hs-libraries: HSbrick-0.19-BFDsYJYOxSCCi5PUtHAYVL
depends:
    base-4.10.0.0 vty-5.17.1-4mTiRtbjX7MIlmTyVTWpDr
    transformers-0.5.2.0 data-clist-0.1.1.0-DMzotO0Z7Aa7X1xqxqeWh4
    dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q containers-0.5.10.2
    microlens-0.4.8.1-HUhGDwljLwYJLac51xSk3I
    microlens-th-0.4.1.1-LM8ksjmIHXtDJYY6zPs0W6
    microlens-mtl-0.1.11.0-LFsRHKdg4sqLRy6hgD5BH2
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    contravariant-1.4-1lqq0vqix8Y43XZ7Q5hTLe
    stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    text-zipper-0.10.1-5anw58L5L9nGBx6ICflo2w template-haskell-2.12.0.0
    deepseq-1.4.3.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             vty-5.17.1-4mTiRtbjX7MIlmTyVTWpDr=0742c0488c1cd6043d5f62d306e276a3
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             data-clist-0.1.1.0-DMzotO0Z7Aa7X1xqxqeWh4=0dfb60216f11e89ee5de81bab18258fb
             dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q=39b750082c56951484aa28fb24175e9c
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             microlens-0.4.8.1-HUhGDwljLwYJLac51xSk3I=1f2768a8b45f6d673f585667eb0cb7d7
             microlens-th-0.4.1.1-LM8ksjmIHXtDJYY6zPs0W6=be9f2fe939681da641c648903d5ef4af
             microlens-mtl-0.1.11.0-LFsRHKdg4sqLRy6hgD5BH2=4b938951cf66f5c51e4cd4b36eae8e21
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             contravariant-1.4-1lqq0vqix8Y43XZ7Q5hTLe=6ad8f06d2a954a3785058f9dadfcb436
             stm-2.4.4.1-4JDnVtQYo787gU0ccBstsJ=a88f5bbac4be96a38c5ca2a658c158a0
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             text-zipper-0.10.1-5anw58L5L9nGBx6ICflo2w=72925df98680edb1f9c2bc74ba58621d
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
haddock-interfaces: /usr/share/doc/haskell-brick/html/brick.haddock
haddock-html: /usr/share/doc/haskell-brick/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
